@@ -161,7 +161,11 @@ def _read_block(docstring: Docstring, offset: int) -> tuple[str, int]:
     return "\n".join(block).rstrip("\n"), new_offset - 1
 
 
-def _read_parameters(docstring: Docstring, offset: int) -> tuple[list[DocstringParameter], int]:  # noqa: WPS231
+def _read_parameters(  # noqa: WPS231
+    docstring: Docstring,
+    offset: int,
+    warn_unknown_params: bool = True,
+) -> tuple[list[DocstringParameter], int]:  # noqa: WPS231
     parameters = []
     annotation: str | Name | Expression | None
 
@@ -202,6 +206,14 @@ def _read_parameters(docstring: Docstring, offset: int) -> tuple[list[DocstringP
         if annotation is None:
             _warn(docstring, line_number, f"No type or annotation for parameter '{name}'")
 
+        if warn_unknown_params and docstring.parent is not None:
+            if name not in docstring.parent.parameters:  # type: ignore[attr-defined]
+                _warn(
+                    docstring,
+                    line_number,
+                    f"Parameter '{name}' does not appear in the parent signature",
+                )
+
         parameters.append(DocstringParameter(name=name, value=default, annotation=annotation, description=description))
 
     return parameters, new_offset
@@ -226,7 +238,7 @@ def _read_other_parameters_section(
     offset: int,
     **options: Any,
 ) -> tuple[DocstringSectionOtherParameters | None, int]:
-    parameters, new_offset = _read_parameters(docstring, offset)
+    parameters, new_offset = _read_parameters(docstring, offset, warn_unknown_params=False)
 
     if parameters:
         return DocstringSectionOtherParameters(parameters), new_offset
@@ -663,6 +675,10 @@ def parse(  # noqa: WPS231
                 else:
                     contents, offset = _read_block(docstring, offset + 1)
                     if contents:
+                        if current_section:
+                            if any(current_section):
+                                sections.append(DocstringSectionText("\n".join(current_section).rstrip("\n")))
+                            current_section = []
                         if title is None:
                             title = admonition_type
                         admonition_type = admonition_type.lower().replace(" ", "-")
